@@ -11,7 +11,7 @@
 
 from __future__ import absolute_import
 
-__version__ = '0.1.13'
+__version__ = '0.1.14'
 
 import hashlib
 import random
@@ -19,7 +19,7 @@ import urlparse
 
 from datetime import timedelta
 
-from flask import session, request, abort
+from flask import g, request, abort
 
 if hasattr(random, 'SystemRandom'):
     randrange = random.SystemRandom().randrange
@@ -69,8 +69,9 @@ class SeaSurf(object):
     this extension is to generate and validate CSRF tokens. The design and
     implementation of this extension is influenced by Django's CSRF middleware.
 
-    Tokens are generated using a salted SHA1 hash. The salt is based off your
-    application's `SECRET_KEY` setting and a random range.
+    Tokens are generated using a salted SHA1 hash. The salt is based off a
+    a random range. The OS's SystemRandom is used if available, otherwise
+    the core random.randrange is used.
 
     You might intialize :class:`SeaSurf` something like this::
 
@@ -122,7 +123,6 @@ class SeaSurf(object):
         # expose the CSRF token to the template
         app.jinja_env.globals['csrf_token'] = self._get_token
 
-        self._secret_key = app.config.get('SECRET_KEY', '')
         self._csrf_name = app.config.get('CSRF_COOKIE_NAME', '_csrf_token')
         self._csrf_disable = app.config.get('CSRF_DISABLE',
                                             app.config.get('TESTING', False))
@@ -187,9 +187,9 @@ class SeaSurf(object):
 
         csrf_token = request.cookies.get(self._csrf_name, None)
         if not csrf_token:
-            session[self._csrf_name] = self._generate_token()
+            setattr(g, self._csrf_name, self._generate_token())
         else:
-            session[self._csrf_name] = csrf_token
+            setattr(g, self._csrf_name, csrf_token)
 
         if request.method not in ('GET', 'HEAD', 'OPTIONS', 'TRACE'):
             # Retrieve the view function based on the request endpoint and
@@ -230,18 +230,19 @@ class SeaSurf(object):
                 return abort(403)
 
     def _after_request(self, response):
-        '''Checks if a request session contains the CSRF token. If so, returns
-        the response. If not then we set a cookie on the response and return
-        the response. Bound to the Flask `after_request` decorator.'''
+        '''Checks if the flask.g object contains the CSRF token. If so, returns
+        the response with a cookie containing the token. If not then we just
+        return the response unaltered. Bound to the Flask `after_request`
+        decorator.'''
 
-        if session.get(self._csrf_name) is None:
+        if getattr(g, self._csrf_name) is None:
             return response
 
-        if not session.get('_csrf_used', False):
+        if not getattr(g, '_csrf_used', False):
             return response
 
         response.set_cookie(self._csrf_name,
-                            session[self._csrf_name],
+                            getattr(g, self._csrf_name),
                             max_age=self._csrf_timeout)
         response.vary.add('Cookie')
         return response
@@ -249,10 +250,10 @@ class SeaSurf(object):
     def _get_token(self):
         '''Attempts to get a token from the request cookies and sets
         `_csrf_used` to True.'''
-        session['_csrf_used'] = True
-        return session.get(self._csrf_name, None)
+        g._csrf_used = True
+        return getattr(g, self._csrf_name, None)
 
     def _generate_token(self):
         '''Generates a token with randomly salted SHA1. Returns a string.'''
-        salt = (randrange(0, _MAX_CSRF_KEY), self._secret_key)
-        return str(hashlib.sha1('%s%s' % salt).hexdigest())
+        salt = randrange(0, _MAX_CSRF_KEY)
+        return str(hashlib.sha1(str(salt)).hexdigest())
